<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Norwegian [NO]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=483
Author: Piwigo team
Author URI: http://piwigo.org
*/

$lang_info['language_name'] = "Norwegian";
$lang_info['country'] = "Norway";
$lang_info['direction'] = "ltr";
$lang_info['code'] = "no";
$lang_info['zero_plural'] = "1";

$lang['useful when password forgotten'] = "Nyttig om passord blir glemt";
$lang['Quick search'] = "Hurtigsøk";
$lang['Connected user: %s'] = "Pålogget bruker: %s";
$lang['IP: %s'] = "IP: %s";
$lang['Browser: %s'] = "Browser: %s";
$lang['Author: %s'] = "Forfatter: %s";
$lang['Comment: %s'] = "Kommentar: %s";
$lang['Comment by %s'] = "Kommentert av %s";
$lang['User: %s'] = "Bruker: %s";
$lang['Email: %s'] = "Email: %s";
$lang['Admin: %s'] = "Admin: %s";
$lang['Registration of %s'] = "Registrering av %s";
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = "Feil status for bruker \"gjest\", default status vil bli brukt. Vennligst kontakt webmaster.";
$lang['this email address is already in use'] = "En annen bruker har allerede denne mail addressen";
$lang['Tag results for'] = "Tag resultat for";
$lang['from %s to %s'] = "fra %s til %s";
$lang['Play of slideshow'] = 'Avspill slideshow';
$lang['Pause of slideshow'] = "Pause slideshow";
$lang['Repeat the slideshow'] = "Gjenta slideshow";
$lang['Not repeat the slideshow'] = "Ikke repeter slideshow";
$lang['Reduce diaporama speed'] = "Reduser slideshow hastighet";
$lang['Accelerate diaporama speed'] = "Øk slideshow hastighet";
$lang['Submit'] = "Send";
$lang['Yes'] = "Ja";
$lang['No'] = "Nei";
$lang['%d photo'] = "%d bilde";
$lang['%d photos'] = "%d bilder";
$lang['%d photo is also linked to current tags'] = "%d bilde er også linket til gjeldende tags";
$lang['%d photos are also linked to current tags'] = "%d bilder er også linket til gjeldende tags";
$lang['display photos linked to this tag'] = "Se kun bilder linket til gjeldende tags";
$lang['photos posted during the last %d days'] = "bilder postet innen de siste %d dager";
$lang['Piwigo Help'] = "Piwigo hjelp";
$lang['Rank'] = "Rangering";
$lang['group by letters'] = "ordne etter bokstav";
$lang['letters'] = "bokstav";
$lang['show tag cloud'] = "vis tags cloud";
$lang['cloud'] = 'sky';
$lang['Reset to default values'] = "Sett tilbake til standard verdier";
$lang['delete all photos from your favorites'] = "slett alle bilder fra dine favoritter";
$lang['Sent by'] = "Sendt av";
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = "Cookies er blokkert eller ikke støttet av din nettleser. Du må aktivere cookies for å logge inn.";
$lang['day'][0] = 'Søndag';
$lang['day'][1] = 'Mandag';
$lang['day'][2] = 'Tirsdag';
$lang['day'][3] = 'Onsdag';
$lang['day'][4] = 'Torsdag';
$lang['day'][5] = 'Fredag';
$lang['day'][6] = 'Lørdag';
$lang['month'][10] = 'Oktober';
$lang['month'][11] = 'November';
$lang['month'][12] = 'Desember';
$lang['month'][1] = 'Januar';
$lang['month'][2] = 'Februar';
$lang['month'][3] = 'Mars';
$lang['month'][4] = 'April';
$lang['month'][5] = 'Mai';
$lang['month'][6] = 'Juni';
$lang['month'][7] = 'July';
$lang['month'][8] = 'August';
$lang['month'][9] = 'September';
$lang['Albums'] = 'Album';
$lang['Album'] = 'Album';
$lang['Close this window'] = 'Lukk dette vinduet';
$lang['Complete RSS feed (photos, comments)'] = 'Komplett RSS mating (bilder, kommentarer)';
$lang['Confirm Password'] = 'Bekreft Passord';
$lang['Connection settings'] = 'Tilkoblings innstillinger';
$lang['Login'] = 'Logg inn';
$lang['Contact webmaster'] = 'Kontakt webmaster';
$lang['Create a new account'] = 'Oprett ny konto';
$lang['Created on'] = 'Oprettet den';
$lang['Creation date'] = 'Dato for opprettelse';
$lang['Current password is wrong'] = 'Passordet er feil';
$lang['Dimensions'] = 'Dimensjoner';
$lang['Display'] = 'Vis';
$lang['Each listed rule must be satisfied.'] = 'Alle listede krav må være oppfylt.';
$lang['Email address'] = 'Email adresse';
$lang['Enter your personnal informations'] = 'Skriv inn dine personlige data';
$lang['Error sending email'] = 'Feil ved sending av e-mail';
$lang['File name'] = 'Fil navn';
$lang['File'] = 'Fil';
$lang['Filesize'] = 'Filstørrelse';
$lang['Filter and display'] = 'Filtrer og vis';
$lang['Filter'] = 'Filter';
$lang['Forgot your password?'] = 'Glemt passord?';
$lang['Go through the gallery as a visitor'] = 'Naviger galleriet som gjest';
$lang['Help'] = 'Hjelp';
$lang['Identification'] = 'Identifikasjon';
$lang['Photos only RSS feed'] = 'Bare bilder RSS feed';
$lang['Keyword'] = 'Nøkkelord';
$lang['Links'] = 'Linker';
$lang['N/A'] = 'N/A';
$lang['New on %s'] = 'Ny den %s';
$lang['%d album updated'] = '%d album oppdatert';
$lang['%d albums updated'] = '%d album oppdatert';
$lang['%d comment to validate'] = '%d kommentar å godkjenne';
$lang['%d comments to validate'] = '%d kommentarer å godkjenne';
$lang['%d new comment'] = '%d ny kommentar';
$lang['%d new comments'] = '%d nye kommentarer';
$lang['%d comment'] = '%d kommentar';
$lang['%d comments'] = '%d kommentarer';
$lang['%d hit'] = '%d treff';
$lang['%d hits'] = '%d treff';
$lang['%d new photo'] = '%d nytt bilde';
$lang['%d new photos'] = '%d nye bilder';
$lang['%d new user'] = '%d ny bruker';
$lang['%d new users'] = '%d nye brukere';
$lang['About'] = 'Om';
$lang['All tags'] = 'Alle ord';
$lang['Any tag'] = 'Valgte ord';
$lang['At least one listed rule must be satisfied.'] = 'Minst en listet regel må være med.';
$lang['At least one tag must match'] = 'Minst et ord må stemme';
$lang['Author'] = 'Forfatter';
$lang['New password confirmation does not correspond'] = 'Nytt passord bekreftelse er ikke lik';
$lang['Notification'] = 'Til informasjon';
$lang['Number of items'] = 'Antall poster';
$lang['Original dimensions'] = 'Orginal dimensjoner';
$lang['Password forgotten'] = 'Glemt passord';
$lang['Password'] = 'Passord';
$lang['Post date'] = 'Post dato';
$lang['Posted on'] = 'Postet den';
$lang['Profile'] = 'Profil';
$lang['Quick connect'] = 'Hurtig tilkobling';
$lang['RSS feed'] = 'RSS mating';
$lang['Register'] = 'Registrere';
$lang['Registration'] = 'Registrering';
$lang['Related tags'] = 'Relaterte ord';
$lang['Reset'] = 'Tibakestill';
$lang['Retrieve password'] = 'Motta passord';
$lang['Search rules'] = 'Søke kriterie';
$lang['Search tags'] = 'Søke ord';
$lang['Search'] = 'Søk';
$lang['display available tags'] = 'Se tilgjengelige tags';
$lang['Since'] = 'Siden';
$lang['Sort by'] = 'Sorter etter';
$lang['Sort order'] = 'Sorter alfabetisk';
$lang['Tag'] = 'Ord';
$lang['Tags'] = 'Ord';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'RSS mater gir varsling om nye aktiviteter fra denne web siden: nye bilder, oppdaterte album, nye kommentarer. For å bli brukt i en RSS leser.';
$lang['Unknown feed identifier'] = 'ukjent mater gjenkjenner';
$lang['User comments'] = 'Bruker kommentarer';
$lang['Username'] = 'Brukernavn';
$lang['Visits'] = 'Besøk';
$lang['Webmaster'] = 'Webmaster';
$lang['About Piwigo'] = 'Om Piwigo';
$lang['You are not authorized to access the requested page'] = 'Du er ikke autorisert til å se ønsket side';
$lang['add to caddie'] = 'legg i kurv';
$lang['add this photo to your favorites'] = 'legg dette bilde til dine favoritter';
$lang['Administration'] = 'Administrasjon';
$lang['all'] = 'alle';
$lang['ascending'] = 'stigende';
$lang['author(s) : %s'] = 'forfatter(e) : %e';
$lang['Expand all albums'] = 'Vis alle album';
$lang['posted after %s (%s)'] = 'postet etter %s (%s)';
$lang['posted before %s (%s)'] = 'postet before %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'postet mellom %s (%s) og %s (%s)';
$lang['posted on %s'] = 'postet den %s';
$lang['Best rated'] = 'Best rangert';
$lang['display best rated photos'] = 'vis de best rangerte bildene';
$lang['caddie'] = 'Kurv';
$lang['Calendar'] = 'Kalender';
$lang['All'] = 'Alle';
$lang['display each day with photos, month per month'] = 'Vis hver dag med bilder, måned etter måned';
$lang['View'] = 'Vis';
$lang['chronology_monthly_calendar'] = 'Månedlig kalender';
$lang['chronology_monthly_list'] = 'Månedlig liste';
$lang['chronology_weekly_list'] = 'Ukentlig liste';
$lang['Click here if your browser does not automatically forward you'] = 'Klikk her pm din nettleser ikke automatisk sender deg viderer.';
$lang['comment date'] = 'Kommentert dato';
$lang['Comment'] = 'kommentar';
$lang['Your comment has been registered'] = 'Din kommentar er registrert';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Overbuffringsvern : Vennligst vent før du prøver å legge til den ny kommentar';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Din kommentar har IKKE blitt registrert da den ikke ble validert';
$lang['An administrator must authorize your comment before it is visible.'] = 'En administrator må godkjenne din kommentar før den blir synlig.';
$lang['This login is already used by another user'] = 'Denne innloggingen er allerede i bruk.';
$lang['Comments'] = 'Kommentarer';
$lang['Add a comment'] = 'Legg til en kommentar';
$lang['created after %s (%s)'] = 'oprettet etter %s (%s)';
$lang['created before %s (%s)'] = 'oprettet før %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'oprettet mellom %s (%s) og %s (%s)';
$lang['created on %s'] = 'oprettet den %s';
$lang['Customize'] = 'Egendefinert';
$lang['Your Gallery Customization'] = 'Ditt galleri egendefinert';
$lang['Default'] = 'Standard';
$lang['delete this photo from your favorites'] = 'slett bildet fra dine favoritter';
$lang['Delete'] = 'Slett';
$lang['descending'] = 'synkende';
$lang['download'] = 'last ned';
$lang['download this file'] = 'last ned denne filen';
$lang['edit'] = 'redigere';
$lang['wrong date'] = 'gal dato';
$lang['excluded'] = 'ekskludert';
$lang['Your favorites'] = 'Mine favoritter';
$lang['display your favorites photos'] = 'vis mine favoritt bilder';
$lang['Favorites'] = 'Favoritter';
$lang['First'] = 'Første';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'Galleriet er stengt for vedlikehold. Vennligst kom tilbake senere.';
$lang['Page generated in'] = 'Side generert i';
$lang['guest'] = 'gjest';
$lang['Hello'] = 'Hallo';
$lang['available for administrators only'] = 'kun tilgjengelig for administrator';
$lang['display this album'] = 'vis bilder fra root i dette albumet';
$lang['display last user comments'] = 'Se siste brukers kommentarer';
$lang['customize the appareance of the gallery'] = 'Egendefiner visning av dette galleriet';
$lang['search'] = 'søk';
$lang['Home'] = 'Hjem';
$lang['in this album'] = 'i dette albumet';
$lang['in %d sub-album'] = 'i % grunnn-album';
$lang['in %d sub-albums'] = 'in % grunn-albumer';
$lang['included'] = 'inkludert';
$lang['Invalid password!'] = 'Ugyldig passord!';
$lang['Language'] = 'Språk';
$lang['last %d days'] = 'siste % dager';
$lang['Last'] = 'Sist';
$lang['Logout'] = 'Logg ut';
$lang['E-mail address'] = 'E-mail addresse';
$lang['obligatory'] = 'obligatorisk';
$lang['Maximum photo height'] = 'Bildets maksimum høyde';
$lang['Maximum height must be a number superior to 50'] = 'Maksimum høyde må være et tall større en 50';
$lang['Maximum photo width'] = 'Bildets maksimums bredde';
$lang['Maximum width must be a number superior to 50'] = 'Maksimum bredde må være et tall større en 50';
$lang['display a calendar by creation date'] = 'vis en kalender fra opprettelses dato';
$lang['display all photos in all sub-albums'] = 'vis alle elementer i alle grunn-albumer';
$lang['return to normal view mode'] = 'tilbake til normalvisning';
$lang['display a calendar by posted date'] = 'vis en kalender etter dato postet';
$lang['Most visited'] = 'Mest besøkte';
$lang['display most visited photos'] = 'vis mest besøkte bilder';
$lang['The number of photos per page must be a not null scalar'] = 'Antall bilder per side må være større en null';
$lang['Number of photos per page'] = 'Antall bilder per side';
$lang['Unknown identifier'] = 'Ukjent identifier';
$lang['New password'] = 'Nytt passord';
$lang['Rate this photo'] = 'Gi karakter på dette bildet';
$lang['Next'] = 'Neste';
$lang['no rate'] = 'ingen karakter';
$lang['Photos posted within the last %d day.'] = 'Elementer posted kun de % siste dager.';
$lang['Photos posted within the last %d days.'] = 'Elementer posted kun de % siste dager.';
$lang['password updated'] = 'passord oppdatert';
$lang['Recent period must be a positive integer value'] = 'Siste periode må være en positiv verdi';
$lang['photo'] = 'bilde';
$lang['Click on the photo to see it in high definition'] = 'Klikk på bildet for å se det i høy oppløsning';
$lang['Show file metadata'] = 'Vis filens metadata';
$lang['Powered by'] = 'Drevet av';
$lang['Preferences'] = 'Referanser';
$lang['Previous'] = 'Forrige';
$lang['Random photos'] = 'Tilfeldige bilder';
$lang['display a set of random photos'] = 'viser en gruppe tilfeldige bilder';
$lang['Recent albums'] = 'Siste album';
$lang['display recently updated albums'] = 'viser nylig oppdaterte album';
$lang['Recent period'] = 'Siste periode';
$lang['Recent photos'] = 'Siste bilder';
$lang['display most recent photos'] = 'Viser de sist sette bilder';
$lang['Redirection...'] = 'Videresender...';
$lang['Please, enter a login'] = 'Vennligst logg inn';
$lang['login mustn\'t end with a space character'] = 'login må ikke ende med et mellomrom';
$lang['login mustn\'t start with a space character'] = 'login må ikke starte med et mellomrom';
$lang['this login is already used'] = 'denne innloggingen er allerede i bruk';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'mail addresse må være tilsvarende xxx@yyy.eee (eksempel : jack@altern.org)';
$lang['please enter your password again'] = 'vennligst skriv ditt passord på ny';
$lang['Auto login'] = 'Auto innlogging';
$lang['%d Kb'] = '%d Kb';
$lang['Week %d'] = 'Uke %d';
$lang['remove this tag from the list'] = 'fjern tag fra denne listen';
$lang['representative'] = 'representative';
$lang['Search for Author'] = 'Søk etter forfatter';
$lang['Search in albums'] = 'Søk i album';
$lang['Search by Date'] = 'Søk etter dato';
$lang['Date'] = 'Dato';
$lang['End-Date'] = 'Ende dato';
$lang['Kind of date'] = 'Slags dato';
$lang['Search for words'] = 'Søk etter ord';
$lang['Search for all terms'] = 'Søk i alle termer';
$lang['Search for any terms'] = 'Søk i hvilken som helst term';
$lang['Empty query. No criteria has been entered.'] = 'Tøm spørring. Ingen kriterier har blitt lagt inn.';
$lang['Search Options'] = 'Søke alternativer';
$lang['Search results'] = 'Søke resultat';
$lang['Search in sub-albums'] = 'Søk i grunn-album';
$lang['searched words : %s'] = 'søkte ord : %';
$lang['Contact'] = 'Kontakt';
$lang['set as album representative'] = 'set som album representant';
$lang['Show number of comments'] = 'Vis antall kommentarer';
$lang['Show number of hits'] = 'Vis antall hit';
$lang['slideshow'] = 'slideshow';
$lang['stop the slideshow'] = 'stop slideshow';
$lang['Specials'] = 'Spesial';
$lang['SQL queries in'] = 'SQL spørring' ;
$lang['display only recently posted photos'] = 'Vis kun sisite postede bilder';
$lang['return to the display of all photos'] = 'tilbake til visning av alle bilder';
$lang['the beginning'] = 'begynnelsen';
$lang['Interface theme'] = 'Brukerfalte tema';
$lang['Thumbnails'] = 'Miniatyrbilder';
$lang['Menu'] = 'Meny';
$lang['A comment on your site'] = 'En kommentar på din side';
$lang['today'] = 'i dag';
$lang['Update your rating'] = 'Oppdater din rating';
$lang['wrong filename'] = 'galt filnavn';
$lang['the username must be given'] = 'brukernavn kreves';
$lang['Album: %s'] = 'Album: %s';
$lang['Album results for'] = 'Album results for';
$lang['edit this comment'] = 'Endre denne kommentaren';
$lang['Edit a comment'] = 'Endre en kommentar';
$lang['Are you sure?'] = 'Er du sikker?';
$lang['(!) This comment requires validation'] = '(!) Denne kommentaren krever godkjenning';
$lang['Welcome'] = 'Velkommen';
$lang['Welcome to your Piwigo photo gallery!'] = 'Velkommen til din Piwigo photo gallery!';
$lang['... or browse your empty gallery'] = '... eller bla i ditt tomme galleri';
$lang['... or please deactivate this message, I will find my way by myself'] = '... eller vennligstdeaktiver denne beskjeden, jeg vil finne ut av det selv';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Hallo %, ditt Piwigo photo gallery er tomt!';
$lang['I want to add photos'] = 'Jeg vil legge til foto';
$lang['Manage this user comment: %s'] = 'Behandle denne brukers kommentar: %er';
$lang['Email address is missing. Please specify an email address.'] = 'Email addresse mangler. Vennligst skriv en email addresse.';
$lang['This author modified following comment:'] = 'Denne forfatteren modifiserte følgende kommentar:';
$lang['This author removed the comment with id %d'] = 'Denne forfatteren fjernetkommentaren med id %d';
$lang['delete this comment'] = 'slett denne kommentaren';
$lang['validate this comment'] = 'godkjenn denne kommentaren';
?>